// This file was generated by ecm_setup_version(): DO NOT EDIT!

#ifndef PLASMA_ACTIVITIES_VERSION_H
#define PLASMA_ACTIVITIES_VERSION_H

#define PLASMA_ACTIVITIES_VERSION_STRING "6.6.91"
#define PLASMA_ACTIVITIES_VERSION_MAJOR 6
#define PLASMA_ACTIVITIES_VERSION_MINOR 6
#define PLASMA_ACTIVITIES_VERSION_PATCH 91
#define PLASMA_ACTIVITIES_VERSION ((6<<16)|(6<<8)|(91))

#endif
